@@ -1,5 +1,6 @@
 import itertools
 import pickle
+import warnings
 from textwrap import dedent
 from urllib.request import urlopen
 
@@ -22,6 +23,7 @@ from ..datasets import (
     anc,
     basin,
     ds_no_attrs,
+    ds_with_tuple,
     dsg,
     forecast,
     mollwds,
@@ -32,7 +34,13 @@ from ..datasets import (
     rotds,
     vert,
 )
-from . import raise_if_dask_computes, requires_cftime, requires_pint, requires_scipy
+from . import (
+    raise_if_dask_computes,
+    requires_cftime,
+    requires_pint,
+    requires_regex,
+    requires_scipy,
+)
 
 mpl.use("Agg")
 
@@ -48,7 +56,10 @@ def assert_dicts_identical(dict1, dict2):
         assert_identical(dict1[k], dict2[k])
 
 
-def test_repr():
+def test_repr() -> None:
+
+    repr(ds_with_tuple.cf)
+
     # Dataset.
     # Stars: axes, coords, and std names
     actual = airds.cf.__repr__()
@@ -198,7 +209,7 @@ def test_repr():
     assert actual == dedent(expected)
 
 
-def test_axes():
+def test_axes() -> None:
     expected = dict(T=["time"], X=["lon"], Y=["lat"])
     actual = airds.cf.axes
     assert actual == expected
@@ -208,7 +219,7 @@ def test_axes():
     assert actual == expected
 
 
-def test_coordinates():
+def test_coordinates() -> None:
     expected = dict(latitude=["lat"], longitude=["lon"], time=["time"])
     actual = airds.cf.coordinates
     assert actual == expected
@@ -219,7 +230,7 @@ def test_coordinates():
 
 
 @requires_pint
-def test_coordinates_quantified():
+def test_coordinates_quantified() -> None:
     # note: import order is important
     from .. import units  # noqa
 
@@ -231,7 +242,7 @@ def test_coordinates_quantified():
     )
 
 
-def test_cell_measures():
+def test_cell_measures() -> None:
     ds = airds.copy(deep=False)
     ds["foo"] = xr.DataArray(ds["cell_area"], attrs=dict(standard_name="foo_std_name"))
     ds["air"].attrs["cell_measures"] += " foo_measure: foo"
@@ -249,7 +260,7 @@ def test_cell_measures():
 
     # Additional cell measure in repr
     actual = ds.cf.__repr__()
-    expected = """\
+    expected_repr = """\
     Data Variables:
     - Cell Measures:   foo_measure: ['foo']
                        volume: ['foo']
@@ -260,10 +271,10 @@ def test_cell_measures():
 
     - Bounds:   n/a
     """
-    assert actual.endswith(dedent(expected))
+    assert actual.endswith(dedent(expected_repr))
 
 
-def test_standard_names():
+def test_standard_names() -> None:
     expected = dict(
         air_temperature=["air"], latitude=["lat"], longitude=["lon"], time=["time"]
     )
@@ -276,21 +287,21 @@ def test_standard_names():
     assert dsnew.cf.standard_names == dict(a=["a", "b"])
 
 
-def test_drop_bounds():
+def test_drop_bounds() -> None:
     assert ambig.cf["latitude"].name == "lat"
     assert ambig.cf["longitude"].name == "lon"
     assert ambig.cf.bounds["latitude"] == ["vertices_latitude"]
     assert ambig.cf.bounds["longitude"] == ["vertices_longitude"]
 
 
-def test_accessor_getattr_and_describe():
+def test_accessor_getattr_and_describe() -> None:
     ds_verta = vert.set_coords(
         (
             "ps",
             "areacella",
         )
     )
-    ds_vertb = xr.decode_cf(vert, decode_coords="all")
+    ds_vertb = xr.decode_cf(vert, decode_coords="all")  # type: ignore
 
     assert ds_verta.cf.cell_measures == ds_vertb.cf.cell_measures
     assert ds_verta.o3.cf.cell_measures == ds_vertb.o3.cf.cell_measures
@@ -300,7 +311,7 @@ def test_accessor_getattr_and_describe():
     assert str(ds_verta.cf) == str(ds_vertb.cf)
 
 
-def test_accessor_getattr_coordinate_Nonetype():
+def test_accessor_getattr_coordinate_Nonetype() -> None:
     ds_vert = vert
     ds_vert["o3"].encoding["coordinates"] = None
     assert ds_vert.o3.cf["latitude"].name == "lat"
@@ -308,7 +319,7 @@ def test_accessor_getattr_coordinate_Nonetype():
     assert ds_vert.cf["latitude"].name == "lat"
 
 
-def test_getitem_standard_name():
+def test_getitem_standard_name() -> None:
     actual = airds.cf["air_temperature"]
     expected = airds["air"]
     assert_identical(actual, expected)
@@ -322,14 +333,14 @@ def test_getitem_standard_name():
     with pytest.raises(KeyError):
         ds.cf["air_temperature"]
     actual = ds.cf[["air_temperature"]]
-    expected = ds[["air", "air2"]]
-    assert_identical(actual, expected)
+    expected_ds = ds[["air", "air2"]]
+    assert_identical(actual, expected_ds)
 
     with pytest.raises(KeyError):
         ds.air.cf["air_temperature"]
 
 
-def test_getitem_ancillary_variables():
+def test_getitem_ancillary_variables() -> None:
     expected = anc.set_coords(["q_error_limit", "q_detection_limit"])["q"]
     assert_identical(anc.cf["q"], expected)
     assert_identical(anc.cf["specific_humidity"], expected)
@@ -337,10 +348,10 @@ def test_getitem_ancillary_variables():
     with pytest.warns(UserWarning):
         anc[["q"]].cf["q"]
 
-    with pytest.warns(None) as record:
+    with warnings.catch_warnings():
+        warnings.simplefilter("error")
         with cf_xarray.set_options(warn_on_missing_variables=False):
             anc[["q"]].cf["q"]
-            assert len(record) == 0
 
     for k in ["ULONG", "ULAT"]:
         assert k not in popds.cf["TEMP"].coords
@@ -349,7 +360,7 @@ def test_getitem_ancillary_variables():
         assert k not in popds.cf["UVEL"].coords
 
 
-def test_rename_like():
+def test_rename_like() -> None:
     # it'll match for axis: X (lon, nlon) and coordinate="longitude" (lon, TLONG)
     # so delete the axis attributes
     original = popds
@@ -405,6 +416,9 @@ def test_rename_like():
     renamed = airds.cf["air"].cf.rename_like(other)
     assert renamed.cf.cell_measures["area"] == ["CELL_AREA"]
 
+    renamed = ds_with_tuple.cf.rename_like(airds)
+    assert renamed.identical(airds)
+
 
 @pytest.mark.parametrize("obj", objects)
 @pytest.mark.parametrize(
@@ -473,7 +487,7 @@ def test_kwargs_methods(obj):
     assert_identical(expected, actual)
 
 
-def test_pos_args_methods():
+def test_pos_args_methods() -> None:
     expected = airds.transpose("lon", "time", "lat")
     actual = airds.cf.transpose("longitude", "T", "latitude")
     assert_identical(actual, expected)
@@ -486,7 +500,7 @@ def test_pos_args_methods():
     assert_identical(actual, expected)
 
 
-def test_preserve_unused_keys():
+def test_preserve_unused_keys() -> None:
 
     ds = airds.copy(deep=False)
     ds.time.attrs.clear()
@@ -495,7 +509,7 @@ def test_preserve_unused_keys():
     assert_identical(actual, expected)
 
 
-def test_kwargs_expand_key_to_multiple_keys():
+def test_kwargs_expand_key_to_multiple_keys() -> None:
 
     actual = multiple.cf.isel(X=5, Y=3)
     expected = multiple.isel(x1=5, y1=3, x2=5, y2=3)
@@ -535,7 +549,7 @@ def test_args_methods(obj):
     assert_identical(expected, actual)
 
 
-def test_dataarray_getitem():
+def test_dataarray_getitem() -> None:
 
     air = airds.air.copy(deep=False)
     air.name = None
@@ -550,7 +564,7 @@ def test_dataarray_getitem():
     assert_identical(air.cf["area_grid_cell"], air.cell_area.reset_coords(drop=True))
 
 
-def test_dataarray_plot():
+def test_dataarray_plot() -> None:
 
     obj = airds.air.copy(deep=False)
 
@@ -651,7 +665,7 @@ def test_getitem_errors(obj):
         obj2.cf["X"]
 
 
-def test_bad_cell_measures_attribute():
+def test_bad_cell_measures_attribute() -> None:
     air2 = airds.copy(deep=False)
     air2.air.attrs["cell_measures"] = "--OPT"
     with pytest.warns(UserWarning):
@@ -677,7 +691,7 @@ def test_bad_cell_measures_attribute():
         air2.cf.cell_measures
 
 
-def test_getitem_clash_standard_name():
+def test_getitem_clash_standard_name() -> None:
     ds = xr.Dataset()
     ds.coords["area"] = xr.DataArray(np.ones(10), attrs={"standard_name": "cell_area"})
     assert_identical(ds.cf["cell_area"], ds["area"].reset_coords(drop=True))
@@ -707,7 +721,7 @@ def test_getitem_clash_standard_name():
     assert_identical(ds["lat"], ds.cf["latitude"])
 
 
-def test_getitem_uses_coordinates():
+def test_getitem_uses_coordinates() -> None:
     # POP-like dataset
     ds = popds
     assert_identical(
@@ -722,7 +736,7 @@ def test_getitem_uses_coordinates():
     assert_identical(ds.TEMP.cf["latitude"], ds["TLAT"].reset_coords(drop=True))
 
 
-def test_getitem_uses_dimension_names_when_coordinates_attr():
+def test_getitem_uses_dimension_names_when_coordinates_attr() -> None:
     # POP-like dataset
     ds = popds
     assert_identical(ds.cf["X"], ds["nlon"])
@@ -731,7 +745,7 @@ def test_getitem_uses_dimension_names_when_coordinates_attr():
     assert_identical(ds.TEMP.cf["Y"], ds["nlat"])
 
 
-def test_plot_xincrease_yincrease():
+def test_plot_xincrease_yincrease() -> None:
     ds = xr.tutorial.open_dataset("air_temperature").isel(time=slice(4), lon=slice(50))
     ds.lon.attrs["positive"] = "down"
     ds.lat.attrs["positive"] = "down"
@@ -796,13 +810,13 @@ def test_add_bounds(dims):
     _check_unchanged(original, ds)
 
 
-def test_add_bounds_multiple():
+def test_add_bounds_multiple() -> None:
     # Test multiple dimensions
     assert not {"x1_bounds", "x2_bounds"} <= set(multiple.variables)
     assert {"x1_bounds", "x2_bounds"} <= set(multiple.cf.add_bounds("X").variables)
 
 
-def test_add_bounds_nd_variable():
+def test_add_bounds_nd_variable() -> None:
     ds = xr.Dataset(
         {"z": (("x", "y"), np.arange(12).reshape(4, 3))},
         coords={"x": np.arange(4), "y": np.arange(3)},
@@ -811,7 +825,7 @@ def test_add_bounds_nd_variable():
     # 2D
     expected = (
         vertices_to_bounds(
-            np.arange(0, 13, 3).reshape(5, 1) + np.arange(-2, 2).reshape(1, 4)
+            np.arange(0, 13, 3).reshape(5, 1) + np.arange(-2, 2).reshape(1, 4)  # type: ignore
         )
         .rename("z_bounds")
         .assign_coords(**ds.coords)
@@ -849,7 +863,7 @@ def test_add_bounds_nd_variable():
         ds.cf.add_bounds("z").cf.add_bounds("x")
 
 
-def test_bounds():
+def test_bounds() -> None:
     ds = airds.copy(deep=False).cf.add_bounds("lat")
 
     actual = ds.cf.bounds
@@ -876,27 +890,28 @@ def test_bounds():
     # Do not attempt to get bounds when extracting a DataArray
     # raise a warning when extracting a Dataset and bounds do not exists
     ds["time"].attrs["bounds"] = "foo"
-    with pytest.warns(None) as record:
+    with warnings.catch_warnings():
+        warnings.simplefilter("error")
         ds.cf["air"]
-    assert len(record) == 0
+
     with pytest.warns(UserWarning, match="{'foo'} not found in object"):
         ds.cf[["air"]]
 
     # Dataset has bounds
-    expected = """\
+    expected_repr = """\
     - Bounds:   Y: ['lat_bounds']
                 lat: ['lat_bounds']
                 latitude: ['lat_bounds']
     """
-    assert dedent(expected) in ds.cf.__repr__()
+    assert dedent(expected_repr) in ds.cf.__repr__()
 
     # DataArray does not have bounds
-    expected = airds.cf["air"].cf.__repr__()
+    expected_repr = airds.cf["air"].cf.__repr__()
     actual = ds.cf["air"].cf.__repr__()
-    assert actual == expected
+    assert actual == expected_repr
 
 
-def test_bounds_to_vertices():
+def test_bounds_to_vertices() -> None:
     # All available
     ds = airds
     original = ds.copy(deep=True)
@@ -926,7 +941,7 @@ def test_bounds_to_vertices():
     _check_unchanged(original, ds)
 
 
-def test_get_bounds_dim_name():
+def test_get_bounds_dim_name() -> None:
     ds = airds.cf.add_bounds("lat")
     assert ds.cf.get_bounds_dim_name("latitude") == "bounds"
     assert ds.cf.get_bounds_dim_name("lat") == "bounds"
@@ -935,7 +950,7 @@ def test_get_bounds_dim_name():
     assert mollwds.cf.get_bounds_dim_name("lon") == "bounds"
 
 
-def test_docstring():
+def test_docstring() -> None:
     assert "One of ('X'" in airds.cf.groupby.__doc__
     assert "Time variable accessor e.g. 'T.month'" in airds.cf.groupby.__doc__
     assert "One or more of ('X'" in airds.cf.mean.__doc__
@@ -944,7 +959,7 @@ def test_docstring():
     assert "present in .indexes" in airds.cf.resample.__doc__
 
     # Make sure docs are up to date
-    get_all_doc = cf_xarray.accessor._get_all.__doc__
+    get_all_doc: str = cf_xarray.accessor._get_all.__doc__  # type: ignore
     all_keys = (
         cf_xarray.accessor._AXIS_NAMES
         + cf_xarray.accessor._COORD_NAMES
@@ -1053,14 +1068,14 @@ def test_guess_coord_axis(kind, names):
         assert dsnew[varname].attrs == ATTRS[kind]
 
 
-def test_guess_coord_axis_datetime():
+def test_guess_coord_axis_datetime() -> None:
     ds = xr.Dataset()
     ds["time"] = ("time", pd.date_range("2001-01-01", "2001-04-01"))
     dsnew = ds.cf.guess_coord_axis()
     assert dsnew.time.attrs == {"standard_name": "time", "axis": "T"}
 
 
-def test_attributes():
+def test_attributes() -> None:
     actual = airds.cf.sizes
     expected = {"X": 50, "Y": 25, "T": 4, "longitude": 50, "latitude": 25, "time": 4}
     assert actual == expected
@@ -1072,7 +1087,7 @@ def test_attributes():
 
     assert airds.cf.chunks == {}
 
-    expected = {
+    expected_chunks = {
         "X": (50,),
         "Y": (5, 5, 5, 5, 5),
         "T": (4,),
@@ -1080,7 +1095,8 @@ def test_attributes():
         "latitude": (5, 5, 5, 5, 5),
         "time": (4,),
     }
-    assert airds.chunk({"lat": 5}).cf.chunks == expected
+    assert airds.chunk({"lat": 5}).cf.chunks == expected_chunks
+    assert airds.chunk({"lat": 5}).cf.chunksizes == expected_chunks
 
     with pytest.raises(AttributeError):
         airds.da.cf.chunks
@@ -1088,19 +1104,18 @@ def test_attributes():
     airds2 = airds.copy(deep=False)
     airds2.lon.attrs = {}
     actual = airds2.cf.sizes
-    expected = {"lon": 50, "Y": 25, "T": 4, "latitude": 25, "time": 4}
-    assert actual == expected
+    expected_sizes = {"lon": 50, "Y": 25, "T": 4, "latitude": 25, "time": 4}
+    assert actual == expected_sizes
 
     actual = popds.cf.data_vars
-    expected = {
+    expected_data_vars = {
         "sea_water_x_velocity": popds.cf["UVEL"],
         "sea_water_potential_temperature": popds.cf["TEMP"],
     }
-    assert_dicts_identical(actual, expected)
+    assert_dicts_identical(actual, expected_data_vars)
 
     actual = multiple.cf.data_vars
-    expected = dict(multiple.data_vars)
-    assert_dicts_identical(actual, expected)
+    assert_dicts_identical(actual, dict(multiple.data_vars))
 
     # check that data_vars contains ancillary variables
     assert_identical(anc.cf.data_vars["specific_humidity"], anc.cf["specific_humidity"])
@@ -1123,14 +1138,14 @@ def test_attributes():
     assert_identical(ds.cf.data_vars["latitude"], ds.cf["ULAT"])
 
 
-def test_missing_variable_in_coordinates():
+def test_missing_variable_in_coordinates() -> None:
     airds.air.attrs["coordinates"] = "lat lon time"
     with xr.set_options(keep_attrs=True):
         # keep bad coordinates attribute after mean
         assert_identical(airds.time, airds.air.cf.mean(["X", "Y"]).cf["time"])
 
 
-def test_Z_vs_vertical_ROMS():
+def test_Z_vs_vertical_ROMS() -> None:
     from ..datasets import romsds
 
     assert_identical(romsds.s_rho.reset_coords(drop=True), romsds.temp.cf["Z"])
@@ -1156,7 +1171,7 @@ def test_Z_vs_vertical_ROMS():
     )
 
 
-def test_param_vcoord_ocean_s_coord():
+def test_param_vcoord_ocean_s_coord() -> None:
     romsds.s_rho.attrs["standard_name"] = "ocean_s_coordinate_g2"
     Zo_rho = (romsds.hc * romsds.s_rho + romsds.Cs_r * romsds.h) / (
         romsds.hc + romsds.h
@@ -1190,7 +1205,7 @@ def test_param_vcoord_ocean_s_coord():
         copy.cf.decode_vertical_coords(outnames={"s_rho": "z_rho"})
 
 
-def test_param_vcoord_ocean_sigma_coordinate():
+def test_param_vcoord_ocean_sigma_coordinate() -> None:
     expected = pomds.zeta + pomds.sigma * (pomds.depth + pomds.zeta)
     pomds.cf.decode_vertical_coords(outnames={"sigma": "z"})
     assert_allclose(pomds.z.reset_coords(drop=True), expected.reset_coords(drop=True))
@@ -1204,7 +1219,7 @@ def test_param_vcoord_ocean_sigma_coordinate():
         copy.cf.decode_vertical_coords(outnames={})
 
 
-def test_formula_terms():
+def test_formula_terms() -> None:
     srhoterms = {
         "s": "s_rho",
         "C": "Cs_r",
@@ -1226,7 +1241,7 @@ def test_formula_terms():
         romsds["zeta"].cf.formula_terms
 
 
-def test_standard_name_mapper():
+def test_standard_name_mapper() -> None:
     da = xr.DataArray(
         np.arange(6),
         dims="time",
@@ -1318,6 +1333,14 @@ def test_rename(obj):
     assert_identical(obj.rename(**xr_dict), obj.cf.rename(**cf_dict))
 
 
+def test_rename_tuple():
+    obj = ds_with_tuple
+
+    cf_dict = {"air_temperature": "renamed"}
+    xr_dict = {(1, 2, 3): "renamed"}
+    assert_identical(obj.rename(xr_dict), obj.cf.rename(cf_dict))
+
+
 @pytest.mark.parametrize("ds", datasets)
 def test_differentiate(ds):
 
@@ -1333,21 +1356,21 @@ def test_differentiate(ds):
         assert_identical(ds.differentiate("lon"), ds.cf.differentiate("X"))
 
 
-def test_new_standard_name_mappers():
+def test_new_standard_name_mappers() -> None:
     assert_identical(forecast.cf.mean("realization"), forecast.mean("M"))
     assert_identical(
         forecast.cf.mean(["realization", "forecast_period"]), forecast.mean(["M", "L"])
     )
     assert_identical(forecast.cf.chunk({"realization": 1}), forecast.chunk({"M": 1}))
     assert_identical(forecast.cf.isel({"realization": 1}), forecast.isel({"M": 1}))
-    assert_identical(forecast.cf.isel(**{"realization": 1}), forecast.isel(**{"M": 1}))
+    assert_identical(forecast.cf.isel(**{"realization": 1}), forecast.isel(**{"M": 1}))  # type: ignore
     assert_identical(
         forecast.cf.groupby("forecast_reference_time.month").mean(),
         forecast.groupby("S.month").mean(),
     )
 
 
-def test_possible_x_y_plot():
+def test_possible_x_y_plot() -> None:
     from ..accessor import _possible_x_y_plot
 
     # choose axes
@@ -1386,7 +1409,7 @@ def test_possible_x_y_plot():
     assert _possible_x_y_plot(xtds, "x", skip="lon") == "T"
 
 
-def test_groupby_special_ops():
+def test_groupby_special_ops() -> None:
     cfgrouped = airds.cf.groupby_bins("latitude", np.arange(20, 50, 10))
     grouped = airds.groupby_bins("lat", np.arange(20, 50, 10))
 
@@ -1466,7 +1489,7 @@ def test_differentiate_positive_upward(obj):
         obj.cf.differentiate("z", positive_upward=True)
 
 
-def test_cmip6_attrs():
+def test_cmip6_attrs() -> None:
     da = xr.DataArray(
         np.ones((10, 10)),
         dims=("nlon", "nlat"),
@@ -1487,7 +1510,7 @@ def test_cmip6_attrs():
     assert da.cf.axes["Y"] == ["nlat"]
 
 
-def test_custom_criteria():
+def test_custom_criteria() -> None:
     my_custom_criteria = {
         "ssh": {
             "standard_name": "sea_surface_elev*|sea_surface_height",
@@ -1568,7 +1591,18 @@ def test_custom_criteria():
         assert_identical(ds.cf["temp"], ds["temperature"])
 
 
-def test_cf_standard_name_table_version():
+@requires_regex
+def test_regex_match():
+    # test that having a global regex expression flag later in the expression will work if
+    # regex is found
+    vocab = {"temp": {"name": "tem|(?i)temp"}}
+    ds = xr.Dataset()
+    ds["Tempblah"] = [0, 1, 2]
+    with cf_xarray.set_options(custom_criteria=vocab):
+        assert_identical(ds.cf["temp"], ds["Tempblah"])
+
+
+def test_cf_standard_name_table_version() -> None:
 
     url = (
         "https://raw.githubusercontent.com/cf-convention/cf-convention.github.io/"
@@ -1579,7 +1613,7 @@ def test_cf_standard_name_table_version():
     assert expected_info == actual_info
 
 
-def test_add_canonical_attributes_0_dim():
+def test_add_canonical_attributes_0_dim() -> None:
     """test if works for variables with 0 dimension"""
     xr.DataArray(
         0, attrs={"standard_name": "sea_water_potential_temperature"}
@@ -1666,13 +1700,13 @@ def test_flag_features(op):
     assert_identical(actual, expected)
 
 
-def test_flag_isin():
+def test_flag_isin() -> None:
     actual = basin.cf.isin(["atlantic_ocean", "pacific_ocean"])
     expected = basin.isin([1, 2])
     assert_identical(actual, expected)
 
 
-def test_flag_errors():
+def test_flag_errors() -> None:
     with pytest.raises(ValueError):
         basin.cf.isin(["arctic_ocean"])
 
@@ -1691,7 +1725,7 @@ def test_flag_errors():
         basin.cf == "pacific_ocean"
 
 
-def test_missing_variables():
+def test_missing_variables() -> None:
 
     # Bounds
     ds = mollwds.copy(deep=False)
@@ -1712,14 +1746,14 @@ def test_missing_variables():
     assert ds.cf.formula_terms == {"lev": {"b": "b", "ps": "ps"}}
 
 
-def test_pickle():
+def test_pickle() -> None:
     da = xr.DataArray([1.0], name="a")
     ds = da.to_dataset()
     pickle.loads(pickle.dumps(da.cf))
     pickle.loads(pickle.dumps(ds.cf))
 
 
-def test_cf_role():
+def test_cf_role() -> None:
     for name in ["profile_id", "trajectory_id"]:
         assert name in dsg.cf.keys()
 
@@ -1733,7 +1767,7 @@ def test_cf_role():
 
 
 @requires_scipy
-def test_curvefit():
+def test_curvefit() -> None:
     from cf_xarray.datasets import airds
 
     def line(time, slope):
@@ -1750,6 +1784,6 @@ def test_curvefit():
 
     actual = airds.air.isel(time=0).curvefit(coords=("lat", "lon"), func=plane)
     expected = airds.air.isel(time=0).cf.curvefit(
-        coords=("latitude", "longitude"), func=plane
+        coords=["latitude", "longitude"], func=plane
     )
     assert_identical(expected, actual)
